@@ -57,10 +57,11 @@ pub trait BuiltinPredicate {
             return SelectBuiltinResult::NoMatch;
         }
         if args.len() == self.arg_groundness().len()
-            && args
-                .iter()
-                .zip(self.arg_groundness().into_iter())
-                .all(|pair| matches!(pair, (_, true) | (IRTerm::Constant(_), false)))
+            && args.iter().zip(self.arg_groundness().into_iter()).all(
+                |(term, allows_ungrounded)| {
+                    *allows_ungrounded || term.is_constant_or_compound_constant()
+                },
+            )
         {
             SelectBuiltinResult::Match
         } else {
@@ -420,6 +421,18 @@ intrinsic_predicate!(
     false,
     false
 );
+intrinsic_predicate!(
+    _operator_set_cmd_begin,
+    crate::analysis::Kind::Image,
+    false,
+    false
+);
+intrinsic_predicate!(
+    _operator_set_cmd_end,
+    crate::analysis::Kind::Image,
+    false,
+    false
+);
 intrinsic_predicate!(
     _operator_set_label_begin,
     crate::analysis::Kind::Image,
@@ -517,6 +530,8 @@ pub fn select_builtin<'a>(
         _operator_set_workdir_end,
         _operator_set_entrypoint_begin,
         _operator_set_entrypoint_end,
+        _operator_set_cmd_begin,
+        _operator_set_cmd_end,
         _operator_set_label_begin,
         _operator_set_label_end,
         _operator_set_env_begin,
@@ -550,6 +565,7 @@ lazy_static! {
         m.insert("copy", (Kind::Image, Kind::Layer));
         m.insert("set_env", (Kind::Image, Kind::Image));
         m.insert("set_entrypoint", (Kind::Image, Kind::Image));
+        m.insert("set_cmd", (Kind::Image, Kind::Image));
         m.insert("set_workdir", (Kind::Image, Kind::Image));
         m.insert("set_label", (Kind::Image, Kind::Image));
         m.insert("append_path", (Kind::Image, Kind::Image));
