@@ -184,6 +184,10 @@ pub enum BuildNode {
         parent: NodeId,
         new_entrypoint: Vec<String>,
     },
+    SetCmd {
+        parent: NodeId,
+        new_cmd: Vec<String>,
+    },
     SetLabel {
         parent: NodeId,
         label: String,
@@ -302,7 +306,7 @@ pub fn build_dag_from_proofs(
                     debug_assert!(substituted_lit
                         .args
                         .iter()
-                        .all(|x| x.as_constant().is_some()));
+                        .all(|x| x.is_constant_or_compound_constant()));
 
                     if !curr_state.has_base() {
                         // Do the optimization mentioned above.
@@ -481,7 +485,8 @@ pub fn build_dag_from_proofs(
                     // TODO: emit a warning if the tree inside attempts
                     // to build a fresh image - this is probably an incorrect usage.
                 }
-                "set_workdir" | "set_entrypoint" | "set_env" | "append_path" | "set_label" => {
+                "set_workdir" | "set_entrypoint" | "set_cmd" | "set_env" | "append_path"
+                | "set_label" => {
                     if curr_state.current_merge.is_some() {
                         panic!("You can not generate a new image inside a merge.");
                     }
@@ -506,12 +511,15 @@ pub fn build_dag_from_proofs(
                             ));
                         }
                         "set_entrypoint" => {
-                            let entrypoint = lit
-                                .args
-                                .iter()
-                                .skip(1)
-                                .map(|x| x.as_constant().unwrap().to_owned())
-                                .collect::<Vec<_>>();
+                            let arg = &lit.args[1];
+                            let entrypoint = match arg {
+                                IRTerm::Constant(c) => vec![c.to_owned()],
+                                IRTerm::Array(ts) => ts
+                                    .iter()
+                                    .map(|t| t.as_constant().unwrap().to_owned())
+                                    .collect(),
+                                _ => unreachable!(),
+                            };
                             curr_state.set_node(res.new_node(
                                 BuildNode::SetEntrypoint {
                                     parent: img,
@@ -520,6 +528,24 @@ pub fn build_dag_from_proofs(
                                 vec![img],
                             ));
                         }
+                        "set_cmd" => {
+                            let arg = &lit.args[1];
+                            let cmd = match arg {
+                                IRTerm::Array(ts) => ts
+                                    .iter()
+                                    .map(|t| t.as_constant().unwrap().to_owned())
+                                    .collect::<Vec<_>>(),
+                                IRTerm::Constant(c) => vec![c.to_owned()],
+                                _ => unreachable!(),
+                            };
+                            curr_state.set_node(res.new_node(
+                                BuildNode::SetCmd {
+                                    parent: img,
+                                    new_cmd: cmd,
+                                },
+                                vec![img],
+                            ));
+                        }
                         "set_env" => {
                             let env_k = lit.args[1].as_constant().unwrap().to_owned();
                             let env_v = lit.args[2].as_constant().unwrap().to_owned();
@@ -673,7 +699,10 @@ pub fn build_dag_from_proofs(
     }
 
     for (query, proof) in query_and_proofs.into_iter() {
-        debug_assert!(query.args.iter().all(|x| x.as_constant().is_some()));
+        debug_assert!(query
+            .args
+            .iter()
+            .all(|x| x.is_constant_or_compound_constant()));
         if let Some(&existing_node_id) = image_literals.get(&query) {
             // TODO: unreachable?
             res.outputs.push(Output {
